==> v_sim-3.1.2.tar.bz2: v_sim-3.1.2/src/extensions/box.h <==
/*   EXTRAITS DE LA LICENCE
	Copyright CEA, contributeurs : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)
  
	Adresse ml :
	BILLARD, non joignable par ml ;
	CALISTE, damien P caliste AT cea P fr.

	Ce logiciel est un programme informatique servant  visualiser des
	structures atomiques dans un rendu pseudo-3D. 

	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
	respectant les principes de diffusion des logiciels libres. Vous pouvez
	utiliser, modifier et/ou redistribuer ce programme sous les conditions
	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
	sur le site "http://www.cecill.info".

	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
	pris connaissance de la licence CeCILL, et que vous en avez accept les
	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
*/

/*   LICENCE SUM UP
	Copyright CEA, contributors : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)

	E-mail address:
	BILLARD, not reachable any more ;
	CALISTE, damien P caliste AT cea P fr.

	This software is a computer program whose purpose is to visualize atomic
	configurations in 3D.

	This software is governed by the CeCILL  license under French law and
	abiding by the rules of distribution of free software.  You can  use, 
	modify and/ or redistribute the software under the terms of the CeCILL
	license as circulated by CEA, CNRS and INRIA at the following URL
	"http://www.cecill.info". 

	The fact that you are presently reading this means that you have had
	knowledge of the CeCILL license and that you accept its terms. You can
	find a copy of this licence shipped with this software at Documentation/licence.en.txt.
*/
#ifndef BOX_H
#define BOX_H

#include <visu_extension.h>
#include <visu_tools.h>


/**
 * initExtensionBox
 *
 * It initialises all variables of the OpenGL extension.
 * It creates all resources and parameters introduced by
 * this extension.
 * This method should be added in the %listInitExtensionFunc to
 * be called automatically by the initOpenGLExtensions() at V_Sim
 * startup.
 *
 * Returns a pointer to the OpenGLExtension it created or
 * NULL otherwise.
 */
OpenGLExtension* initExtensionBox();

/**
 * setBoxRGBValues:
 * @rgb: a three floats array with values (0 <= values <= 1) for the
 * red, the green and the blue color. Only values specified by the mask
 * are really relevant.
 * @mask: use #MASK_RGB_R, #MASK_RGB_G, #MASK_RGB_B, #MASK_RGB_ALL or a
 * combinaison to indicate what values in the rgb array must be taken
 * into account.
 *
 * Method used to change the value of the parameter box_color.
 *
 * Returns 0 if redrawing is not necessary.
 * 1 if the rendering window must be redrawn.
 */
int setBoxRGBValues(float rgb[3], int mask);
/**
 * setBoxLineWidth:
 * @width: value of the desired box line width.
 *
 * Method used to change the value of the parameter box_line_width.
 *
 * Returns 0 if redrawing is not necessary.
 * 1 if the rendering window must be redrawn.
 */
int setBoxLineWidth(float width);
/**
 * setBoxIsOn:
 * @value: 1 if box must be drawn, 0 otherwise.
 *
 * Method used to change the value of the parameter box_is_on.
 *
 * Returns 0 if redrawing is not necessary.
 * 1 if the rendering window must be redrawn.
 */
int setBoxIsOn(int value);

/**
 * getBoxRedValue:
 *
 * Returns: the red value of the current box line color.
 */
float getBoxRedValue();
/**
 * getBoxGreenValue:
 *
 * Returns: the green value of the current box line color.
 */
float getBoxGreenValue();
/**
 * getBoxBlueValue:
 *
 * Returns: the blue value of the current box line color.
 */
float getBoxBlueValue();
/**
 * isBoxOn:
 *
 * Returns: 1 if a box is drawn, 0 otherwise.
 */
int isBoxOn();
/**
 * getBoxLineWidth:
 *
 * Returns: the value of current box line width.
 */
float getBoxLineWidth();




/****************/
/* Private part */
/****************/

OpenGLExtension* extensionBox;

void createBox(GObject *obj, gpointer data);


#endif

==> v_sim-3.2.1.tar.bz2: v_sim-3.2.1/src/extensions/box.h <==
/*   EXTRAITS DE LA LICENCE
	Copyright CEA, contributeurs : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2006)
  
	Adresse ml :
	BILLARD, non joignable par ml ;
	CALISTE, damien P caliste AT cea P fr.

	Ce logiciel est un programme informatique servant  visualiser des
	structures atomiques dans un rendu pseudo-3D. 

	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
	respectant les principes de diffusion des logiciels libres. Vous pouvez
	utiliser, modifier et/ou redistribuer ce programme sous les conditions
	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
	sur le site "http://www.cecill.info".

	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
	pris connaissance de la licence CeCILL, et que vous en avez accept les
	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
*/

/*   LICENCE SUM UP
	Copyright CEA, contributors : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2006)

	E-mail address:
	BILLARD, not reachable any more ;
	CALISTE, damien P caliste AT cea P fr.

	This software is a computer program whose purpose is to visualize atomic
	configurations in 3D.

	This software is governed by the CeCILL  license under French law and
	abiding by the rules of distribution of free software.  You can  use, 
	modify and/ or redistribute the software under the terms of the CeCILL
	license as circulated by CEA, CNRS and INRIA at the following URL
	"http://www.cecill.info". 

	The fact that you are presently reading this means that you have had
	knowledge of the CeCILL license and that you accept its terms. You can
	find a copy of this licence shipped with this software at Documentation/licence.en.txt.
*/
#ifndef BOX_H
#define BOX_H

#include <visu_extension.h>
#include <visu_tools.h>


/**
 * initExtensionBox
 *
 * It initialises all variables of the OpenGL extension.
 * It creates all resources and parameters introduced by
 * this extension.
 * This method should be added in the %listInitExtensionFunc to
 * be called automatically by the initOpenGLExtensions() at V_Sim
 * startup.
 *
 * Returns a pointer to the OpenGLExtension it created or
 * NULL otherwise.
 */
OpenGLExtension* initExtensionBox();

/**
 * boxSet_RGBValues:
 * @rgb: a three floats array with values (0 <= values <= 1) for the
 * red, the green and the blue color. Only values specified by the mask
 * are really relevant.
 * @mask: use #MASK_RGB_R, #MASK_RGB_G, #MASK_RGB_B, #MASK_RGB_ALL or a
 * combinaison to indicate what values in the rgb array must be taken
 * into account.
 *
 * Method used to change the value of the parameter box_color.
 *
 * Returns: 1 if boxDraw() should be called and then 'OpenGLAskForReDraw'
 *          signal be emitted.
 */
int boxSet_RGBValues(float rgb[3], int mask);
/**
 * boxSet_lineWidth:
 * @width: value of the desired box line width.
 *
 * Method used to change the value of the parameter box_line_width.
 *
 * Returns: 1 if boxDraw() should be called and then 'OpenGLAskForReDraw'
 *          signal be emitted.
 */
int boxSet_lineWidth(float width);
/**
 * boxSet_isOn:
 * @value: 1 if box must be drawn, 0 otherwise.
 *
 * Method used to change the value of the parameter box_is_on.
 *
 * Returns: 1 if boxDraw() should be called. In all cases, 'OpenGLAskForReDraw'
 *          signal should then be emitted.
 */
int boxSet_isOn(int value);

/**
 * boxGet_redValue:
 *
 * Returns: the red value of the current box line color.
 */
float boxGet_redValue();
/**
 * boxGet_greenValue:
 *
 * Returns: the green value of the current box line color.
 */
float boxGet_greenValue();
/**
 * boxGet_blueValue:
 *
 * Returns: the blue value of the current box line color.
 */
float boxGet_blueValue();
/**
 * boxGet_isOn:
 *
 * Returns: 1 if a box is drawn, 0 otherwise.
 */
int boxGet_isOn();
/**
 * boxGet_lineWidth:
 *
 * Returns: the value of current box line width.
 */
float boxGet_lineWidth();
/**
 * boxDraw:
 * @data: a #VisuData object.
 *
 * This method create a compile list that draw a box for the given @data.
 */
void boxDraw(VisuData *data);




/****************/
/* Private part */
/****************/

OpenGLExtension* extensionBox;


#endif
